@@ -29,22 +29,13 @@ TASK_PRIO_HIGH = 4
 @shared_task(base=QueueOnce, acks_late=True)
 def send_messages_for_webhook(webhook_pk: int) -> None:
     """sends all currently queued messages for given webhook to Discord"""
-    try:
-        webhook = DiscordWebhook.objects.get(pk=webhook_pk)
-    except DiscordWebhook.DoesNotExist:
-        logger.error(
-            "DiscordWebhook with pk = %s does not exist. Aborting.", webhook_pk
-        )
-    else:
-        if not webhook.is_enabled:
-            logger.info(
-                "Tracker %s: DiscordWebhook disabled - skipping sending", webhook
-            )
-            return
-
-        logger.info("Started sending messages to webhook %s", webhook)
-        webhook.send_queued_messages()
-        logger.info("Completed sending messages to webhook %s", webhook)
+    webhook = DiscordWebhook.objects.get(pk=webhook_pk)
+    if not webhook.is_enabled:
+        logger.info("Tracker %s: DiscordWebhook disabled - skipping sending", webhook)
+        return
+    logger.info("Started sending messages to webhook %s", webhook)
+    webhook.send_queued_messages()
+    logger.info("Completed sending messages to webhook %s", webhook)
 
 
 @shared_task(base=QueueOnce, bind=True, acks_late=True)
@@ -113,115 +104,67 @@ def send_scheduled_notification(self, scheduled_notification_pk: int) -> None:
 
 @shared_task
 def notify_about_new_timer(timer_pk: int, notification_rule_pk: int) -> None:
-    try:
-        timer = Timer.objects.get(pk=timer_pk)
-        notification_rule = NotificationRule.objects.select_related("webhook").get(
-            pk=notification_rule_pk
+    timer = Timer.objects.get(pk=timer_pk)
+    notification_rule = NotificationRule.objects.select_related("webhook").get(
+        pk=notification_rule_pk
+    )
+
+    if notification_rule.is_enabled and notification_rule.webhook.is_enabled:
+        author_text = f" by **{timer.eve_character}**" if timer.eve_character else ""
+        content = f"New timer added{author_text}:"
+        timer.send_notification(
+            webhook=notification_rule.webhook,
+            content=notification_rule.prepend_ping_text(content),
         )
-    except Timer.DoesNotExist:
-        logger.error("Timer with pk = %s does not exist. Aborting.", timer_pk)
-    except NotificationRule.DoesNotExist:
-        logger.error(
-            "NotificationRule with pk = %s does not exist. Aborting.",
-            notification_rule_pk,
+        send_messages_for_webhook.apply_async(
+            args=[notification_rule.webhook.pk], priority=TASK_PRIO_HIGH
         )
-    else:
-        if notification_rule.is_enabled and notification_rule.webhook.is_enabled:
-            author_text = (
-                f" by **{timer.eve_character}**" if timer.eve_character else ""
-            )
-            content = f"New timer added{author_text}:"
-            timer.send_notification(
-                webhook=notification_rule.webhook,
-                content=notification_rule.prepend_ping_text(content),
-            )
-            send_messages_for_webhook.apply_async(
-                args=[notification_rule.webhook.pk], priority=TASK_PRIO_HIGH
-            )
-
-
-def _schedule_notification_for_timer(
-    timer: Timer, notification_rule: NotificationRule
-) -> ScheduledNotification:
-    logger.info(
-        "Scheduling fresh notification for timer #%d, rule #%d",
-        timer.pk,
-        notification_rule.pk,
-    )
-    notification_date = timer.date - timedelta(minutes=notification_rule.scheduled_time)
-    scheduled_notification, _ = ScheduledNotification.objects.update_or_create(
-        timer=timer,
-        notification_rule=notification_rule,
-        defaults={"timer_date": timer.date, "notification_date": notification_date},
-    )
-    result = send_scheduled_notification.apply_async(
-        kwargs={"scheduled_notification_pk": scheduled_notification.pk},
-        eta=timer.date - timedelta(minutes=notification_rule.scheduled_time),
-        priority=TASK_PRIO_HIGH,
-    )
-    scheduled_notification.celery_task_id = result.task_id
-    scheduled_notification.save()
-
-    return scheduled_notification
-
-
-def _revoke_notification_for_timer(
-    scheduled_notification: ScheduledNotification,
-) -> None:
-    logger.info(
-        "Removing stale notification for timer #%d, rule #%d",
-        scheduled_notification.timer.pk,
-        scheduled_notification.notification_rule.pk,
-    )
-    scheduled_notification.delete()
 
 
 @shared_task(acks_late=True)
 def schedule_notifications_for_timer(timer_pk: int, is_new: bool = False) -> None:
     """Schedules notifications for this timer based on notification rules"""
-    try:
-        timer = Timer.objects.get(pk=timer_pk)
-    except Timer.DoesNotExist:
-        logger.error("Timer with pk = %s does not exist. Aborting.", timer_pk)
-    else:
-        if timer.date > now():
-            # trigger: newly created
-            if is_new:
-                rules = (
-                    NotificationRule.objects.select_related("webhook")
-                    .filter(
-                        is_enabled=True,
-                        trigger=NotificationRule.Trigger.NEW_TIMER_CREATED,
-                        webhook__is_enabled=True,
-                    )
-                    .conforms_with_timer(timer)
-                )
-                if rules:
-                    for rule in rules:
-                        notify_about_new_timer.apply_async(
-                            kwargs={
-                                "timer_pk": timer.pk,
-                                "notification_rule_pk": rule.pk,
-                            },
-                            priority=TASK_PRIO_HIGH,
-                        )
-
-            # trigger: timer elapses soon
-            with transaction.atomic():
-                # remove existing scheduled notifications if date has changed
-                for obj in timer.scheduled_notifications.exclude(timer_date=timer.date):
-                    _revoke_notification_for_timer(scheduled_notification=obj)
-
-                # schedule new notifications
-                for notification_rule in NotificationRule.objects.filter(
+    timer = Timer.objects.get(pk=timer_pk)
+    if not timer.date:
+        raise ValueError(f"Not supported for prelimiary timers: {timer}")
+    if timer.date > now():
+        # trigger: newly created
+        if is_new:
+            rules = (
+                NotificationRule.objects.select_related("webhook")
+                .filter(
                     is_enabled=True,
-                    trigger=NotificationRule.Trigger.SCHEDULED_TIME_REACHED,
-                ).conforms_with_timer(timer):
-                    _schedule_notification_for_timer(
-                        timer=timer, notification_rule=notification_rule
+                    trigger=NotificationRule.Trigger.NEW_TIMER_CREATED,
+                    webhook__is_enabled=True,
+                )
+                .conforms_with_timer(timer)
+            )
+            if rules:
+                for rule in rules:
+                    notify_about_new_timer.apply_async(
+                        kwargs={
+                            "timer_pk": timer.pk,
+                            "notification_rule_pk": rule.pk,
+                        },
+                        priority=TASK_PRIO_HIGH,
                     )
-        else:
-            logger.warning("Can not schedule notification for past timer: %s", timer)
+
+        # trigger: timer elapses soon
+        with transaction.atomic():
+            # remove existing scheduled notifications if date has changed
+            for obj in timer.scheduled_notifications.exclude(timer_date=timer.date):
+                _revoke_notification_for_timer(scheduled_notification=obj)
+
+            # schedule new notifications
+            for notification_rule in NotificationRule.objects.filter(
+                is_enabled=True,
+                trigger=NotificationRule.Trigger.SCHEDULED_TIME_REACHED,
+            ).conforms_with_timer(timer):
+                _schedule_notification_for_timer(
+                    timer=timer, notification_rule=notification_rule
+                )
+    else:
+        logger.warning("Can not schedule notification for past timer: %s", timer)
 
 
 @shared_task(acks_late=True)
@@ -261,6 +204,44 @@ def schedule_notifications_for_rule(notification_rule_pk: int) -> None:
                     )
 
 
+def _schedule_notification_for_timer(
+    timer: Timer, notification_rule: NotificationRule
+) -> ScheduledNotification:
+    if timer.timer_type == Timer.Type.PRELIMINARY:
+        raise ValueError(f"Can not schedule prelimiary timers: {timer}")
+    logger.info(
+        "Scheduling fresh notification for timer #%d, rule #%d",
+        timer.pk,
+        notification_rule.pk,
+    )
+    notification_date = timer.date - timedelta(minutes=notification_rule.scheduled_time)
+    scheduled_notification, _ = ScheduledNotification.objects.update_or_create(
+        timer=timer,
+        notification_rule=notification_rule,
+        defaults={"timer_date": timer.date, "notification_date": notification_date},
+    )
+    result = send_scheduled_notification.apply_async(
+        kwargs={"scheduled_notification_pk": scheduled_notification.pk},
+        eta=timer.date - timedelta(minutes=notification_rule.scheduled_time),
+        priority=TASK_PRIO_HIGH,
+    )
+    scheduled_notification.celery_task_id = result.task_id
+    scheduled_notification.save()
+
+    return scheduled_notification
+
+
+def _revoke_notification_for_timer(
+    scheduled_notification: ScheduledNotification,
+) -> None:
+    logger.info(
+        "Removing stale notification for timer #%d, rule #%d",
+        scheduled_notification.timer.pk,
+        scheduled_notification.notification_rule.pk,
+    )
+    scheduled_notification.delete()
+
+
 @shared_task
 def send_test_message_to_webhook(webhook_pk: int, user_pk: int = None) -> None:
     """send a test message to given webhook.
